### Name: contour.lm
### Title: Surface plot(s) of a fitted linear model
### Aliases: contour.lm image.lm persp.lm
### Keywords: regression hplot

### ** Examples

library (rsm)
heli.rsm = rsm (ave ~ block + SO(x1, x2, x3, x4), data = heli)

# Plain contour plots
par (mfrow = c (2,3))
contour (heli.rsm, ~x1+x2+x3+x4, at=canonical(heli.rsm)$xs)

# Same with image overlay and extra annotations showing 
# stationary point and "at" values
# Demonstrates use of 'hook' argument
xs = canonical(heli.rsm)$xs
myhook = list()
myhook$post.plot = function(lab) {
  idx = sapply(lab[3:4], grep, names(xs))
  points (xs[idx[1]], xs[idx[2]], pch=2, col="red")
  main = paste("Predicted response versus", lab[3], "and", lab[4])  
  atlabs = paste(names(xs[-idx]), round(xs[-idx], 3), sep = " = ")
  atlabs = paste(atlabs, collapse = ", ")
  title(c(main, paste("at", atlabs)))
}
contour (heli.rsm, ~x1+x2+x3+x4, at=xs, hook=myhook, image=TRUE)

# Default perspective views
persp (heli.rsm, ~x1+x2+x3+x4, at=canonical(heli.rsm)$xs)

# Same plots, souped-up with facet coloring and axis labeling
persp (heli.rsm, ~x1+x2+x3+x4, contours="col", col=rainbow(40), at=canonical(heli.rsm)$xs,
  xlabs = c("Wing area", "Wing length", "Body width", "Body length"), zlab = "Flight time")
  
## Not run: 
##D ### Hints for creating graphics files for use in publications...
##D 
##D # Save perspective plots in one PDF file (will be six pages long)
##D pdf(file = "heli-plots.pdf")
##D persp (heli.rsm, ~x1+x2+x3+x4, at=canonical(heli.rsm)$xs)
##D dev.off()
##D 
##D # Save perspective plots in six separate PNG files
##D png.hook = list()
##D png.hook$pre.plot = function(lab) 
##D     png(file = paste(lab[3], lab[4], ".png", sep = ""))
##D png.hook$post.plot = function(lab)
##D     dev.off()
##D persp (heli.rsm, ~x1+x2+x3+x4, at=canonical(heli.rsm)$xs, hook = png.hook)
## End(Not run) 



